@@ -8,7 +8,7 @@ import shutil
 import pkg_resources
 from starterpyth import defaults
 from starterpyth.fields import RegexpInput, CharInput, ChoiceInput, BooleanInput
-from starterpyth.utils import py3k_unicode
+from starterpyth.utils import py3k_unicode, normalize_str
 
 __author__ = 'd9pouces'
 
@@ -17,10 +17,12 @@ from starterpyth.translation import ugettext as _
 
 
 licenses = [('cecill a', 'cecill_a'), ('cecill b', 'cecill_b'), ('cecill c', 'cecill_c'), ('lpgl 2', 'lgpl_2'),
-            ('lgpl 3', 'lgpl3'), ('gpl2', 'gpl_2'), ('gpl3', 'gpl_3'), ('other', 'Other')]
+            ('lgpl 3', 'lgpl3'), ('gpl2', 'gpl_2'), ('gpl3', 'gpl_3'), ('other', 'Other'), ('Apache 2.0', 'apache_2'),
+            ('MIT', 'mit'), ('BSD 2 Clauses', 'bsd_2_clauses')]
 license_names = {
     'cecill_a': 'CeCILL-A', 'cecill_b': 'CeCILL-B', 'cecill_c': 'CeCILL-C', 'lgpl_2': 'LGPL 2',
     'lgpl_3': 'LGPL 3', 'gpl_2': 'GPL 2', 'gpl 3': 'GPL 3', 'Other': 'Other license',
+    'apache_2' : 'Apache 2.0', 'mit' : 'MIT', 'bsd_2_clauses' : 'BSD 2 Clauses',
 }
 pyversions = [('2.6', 2.6), ('2.7', 2.7), ('3.0', 3.0), ('3.1', 3.1), ('3.2', 3.2), ('3.3', 3.3), ('3.4', 3.4)]
 
@@ -31,7 +33,7 @@ class BasePlugin(Plugin):
         module_name = RegexpInput(_('Python module name'), regexp=r'[A-Za-z]\w*', default=project_name.lower()).input()
         company = CharInput(_('Company name'), max_length=255, blank=True, default=defaults.COMPANY).input()
         author = CharInput(_('Author name'), max_length=255, default=defaults.AUTHOR).input()
-        email = RegexpInput(_('Author e-mail'), default='%s@%s' % (author, company),
+        email = RegexpInput(_('Author e-mail'), default='%s@%s' % (normalize_str(author), normalize_str(company)),
                             regexp=r'[\w_\-\.]+@[\w_\-\.]').input()
         license_ = ChoiceInput(_('License'), choices=licenses, blank=True, default='cecill b').input()
         pyversion = ChoiceInput(_('Minimum Python version'), choices=pyversions, default='2.7').input()
@@ -59,6 +61,7 @@ class BasePlugin(Plugin):
         context['use_six'] = use_six
         context['py3compat'] = py3compat
         context['license'] = license_names[license_]
+        context['file_encoding'] = "#coding=utf-8\n"
         if license_ != 'Other':
             licence_fd = pkg_resources.resource_stream('starterpyth.plugins.base', 'licenses/%s.txt' % license_)
             context['license_content'] = licence_fd.read().decode('utf-8')
@@ -102,7 +105,7 @@ class BasePlugin(Plugin):
         path = os.path.join(context['project_root'], project_name)
         if os.path.isdir(path):
             rm_choice = ChoiceInput(_('The folder %(f)s already exists. Remove it?') % {'f': path}, default='yes',
-                             choices=(('yes', 'yes'), ('no', 'no'))).input()
+                                    choices=(('yes', 'yes'), ('no', 'no'))).input()
             if rm_choice == 'yes':
                 shutil.rmtree(path)
 
@@ -117,4 +120,4 @@ class BasePlugin(Plugin):
                     '{{module_name}}/locale/xx_XX/LC_MESSAGES',
                     '{{module_name}}/locale/xx_XX/LC_MESSAGES/{{module_name}}.mo',
                     '{{module_name}}/locale/xx_XX/LC_MESSAGES/{{module_name}}.po']
-        return []
\ No newline at end of file
+        return []
